class SeleniumRequestException(Exception):
    pass


class SeleniumOpenTabException(Exception): ...
